---
title: Common questions
slug: Learn/Common_questions
tags:
  - CodingScripting
  - Infrastructure
  - Learn
  - Web
  - WebMechanics
---
{{LearnSidebar}}

This section of the Learning Area is designed to provide answers to common questions that may come
up, which are not necessarily part of the structured core learning pathways (e.g. the [HTML](/en-US/docs/Learn/HTML) or [CSS](/en-US/docs/Learn/CSS) learning articles.) These articles
are designed to work on their own.

## Web mechanics

This section covers questions relating to general knowledge of the web ecosystem and how it works.

- [How does the Internet work?](/en-US/docs/Learn/Common_questions/How_does_the_Internet_work)
  - : The **Internet** is the backbone of the web, the technical infrastructure that makes the web possible.
    At its most basic, the Internet is a massive network of computers communicating with each other. This article
    discusses how it works, in broad terms.
- [What is the difference between
  webpage, website, web server, and search engine?](/en-US/docs/Learn/Common_questions/Pages_sites_servers_and_search_engines)
  - : In this article we describe various web-related concepts: webpages, websites, web servers, and search engines. These
    terms are often a source of confusion for newcomers to the web, or are used incorrectly. Let's discover what they
    actually mean!
- [What are hyperlinks?](/en-US/docs/Learn/Common_questions/What_are_hyperlinks)
  - : In this article, we'll go over what hyperlinks are and why they matter.
- [What is a URL?](/en-US/docs/Learn/Common_questions/What_is_a_URL)
  - : With {{Glossary("Hypertext")}} and {{Glossary("HTTP")}}, URL is a key concept when it comes to the Internet. It is
    the mechanism used by {{Glossary("Browser","browsers")}} to retrieve any published resource on the web.
- [What is a domain name?](/en-US/docs/Learn/Common_questions/What_is_a_domain_name)
  - : Domain names are a key component of the Internet infrastructure. They provide a human-readable address for any web
    server available on the Internet.
- [What is a web server?](/en-US/docs/Learn/Common_questions/What_is_a_web_server)
  - : The term "web server" can refer to the hardware or software that serves websites to clients across the web — or both
    of them working together. In this article we go over how web servers work, and why they're important.

## Tools and setup

Questions related to the tools/software you can use to build websites.

- [What software do I need to build a website?](/en-US/docs/Learn/Common_questions/What_software_do_I_need)
  - : In this article we explain which software components you need to edit, upload, or view a website.
- [How much does it cost to do something on the
  web?](/en-US/docs/Learn/Common_questions/How_much_does_it_cost)
  - : When you're launching a website, you may spend nothing or your costs may go through the roof. In this article we
    discuss how much everything costs and what you get for what you pay (or don't pay).
- [What text editors are available?](/en-US/docs/Learn/Common_questions/Available_text_editors)
  - : In this article we highlight some things to think about when choosing and installing a text editor for web
    development.
- [What are browser developer tools?](/en-US/docs/Learn/Common_questions/What_are_browser_developer_tools)
  - : Every browser features a set of devtools for debugging HTML, CSS, and other web code. This article explains how to
    use the basic functions of your browser's devtools.
- [How do you make sure your
  website works properly?](/en-US/docs/Learn/Common_questions/Checking_that_your_web_site_is_working_properly)
  - : So you've published your website online — very good! But are you sure it works properly? This article provides some
    basic troubleshooting steps.
- [How do you set up a local testing
  server?](/en-US/docs/Learn/Common_questions/set_up_a_local_testing_server)
  - : This article explains how to set up a simple local testing server on your machine, and the basics of how to use it.
- [How do you upload files to a web server?](/en-US/docs/Learn/Common_questions/Upload_files_to_a_web_server)
  - : This article shows how to publish your site online with {{Glossary("FTP")}} tools — one of the most common ways to get a website online so others can access it from their computers.
- [How do I use GitHub
  Pages?](/en-US/docs/Learn/Common_questions/Using_Github_pages)
  - : This article provides a basic guide to publishing content using GitHub's gh-pages feature.
- [How do you host your website
  on Google App Engine?](/en-US/docs/Learn/Common_questions/How_do_you_host_your_website_on_Google_App_Engine)
  - : Looking for a place to host your website? Here's a step-by-step guide to hosting your website on Google App Engine.
- [What
  tools are available to debug and improve website performance?](/en-US/docs/Tools/Performance)
  - : This set of articles shows you how to use the Developer Tools in Firefox to debug and improve performance of your
    website, using the tools to check memory usage, the JavaScript call tree, the number of DOM nodes being rendered, and
    more.

## Design and accessibility

This section lists questions related to aesthetics, page structure, accessibility techniques, etc.

- [How do
  I start to design my website?](/en-US/docs/Learn/Common_questions/Thinking_before_coding)
  - : This article covers the all-important first step of every project: define what you want to accomplish with it.
- [What do
  common web layouts contain?](/en-US/docs/Learn/Common_questions/Common_web_layouts)
  - : When designing pages for your website, it's good to have an idea of the most common layouts. This article runs
    through some typical web layouts, looking at the parts that make up each one.
- [What is
  accessibility?](/en-US/docs/Learn/Common_questions/What_is_accessibility)
  - : This article introduces the basic concepts behind web accessibility.
- [How can we design for all types of
  users?](/en-US/docs/Learn/Common_questions/Design_for_all_types_of_users)
  - : This article provides basic techniques to help you design websites for any kind of user — quick accessibility wins,
    and other such things.
- [What HTML features promote
  accessibility?](/en-US/docs/Learn/Common_questions/HTML_features_for_accessibility)
  - : This article describes specific features of HTML that can be used to make a webpage more accessible to people with
    different disabilities.

## HTML, CSS and JavaScript questions

For common solutions to HTML/CSS/JavaScript problems, try the following articles:

- [Use HTML to solve common problems](/en-US/docs/Learn/HTML/Howto)
- [Use CSS to solve common problems](/en-US/docs/Learn/CSS/Howto)
- [Use JavaScript to solve common problems](/en-US/docs/Learn/JavaScript/Howto)
