---
title: 'Element: keydown event'
slug: Web/API/Element/keydown_event
tags:
  - API
  - DOM
  - Element
  - Event
  - KeyboardEvent
  - Reference
  - keyboard
  - keydown
browser-compat: api.Element.keydown_event
---
{{APIRef}}

The **`keydown`** event is fired when a key is pressed.

Unlike the {{Event("keypress")}} event, the `keydown` event is fired for all keys, regardless of whether they produce a character value.

<table class="properties">
  <tbody>
    <tr>
      <th>Bubbles</th>
      <td>Yes</td>
    </tr>
    <tr>
      <th>Cancelable</th>
      <td>Yes</td>
    </tr>
    <tr>
      <th>Interface</th>
      <td>{{domxref("KeyboardEvent")}}</td>
    </tr>
    <tr>
      <th>Event handler property</th>
      <td>
        {{domxref("GlobalEventHandlers.onkeydown", "onkeydown")}}
      </td>
    </tr>
  </tbody>
</table>

The `keydown` and [`keyup`](/en-US/docs/Web/API/Element/keyup_event) events provide a code indicating which key is pressed, while `keypress` indicates which character was entered. For example, a lowercase "a" will be reported as 65 by `keydown` and `keyup`, but as 97 by `keypress`. An uppercase "A" is reported as 65 by all events.

Keyboard events are only generated by `<inputs>`, `<textarea>` and anything with the `contentEditable` attribute or with `tabindex="-1"`.

Since Firefox 65, the `keydown` and [`keyup`](/en-US/docs/Web/API/Element/keyup_event) events are now fired during IME composition, to improve cross-browser compatibility for CJKT users ({{bug(354358)}}. To ignore all `keydown` events that are part of composition, do something like this (229 is a special value set for a `keyCode` relating to an event that has been processed by an IME):

```js
eventTarget.addEventListener("keydown", event => {
  if (event.isComposing || event.keyCode === 229) {
    return;
  }
  // do something
});
```

## Examples

### addEventListener keydown example

This example logs the {{domxref("KeyboardEvent.code")}} value whenever you press down a key inside the {{HtmlElement("input")}} element.

```html
<input placeholder="Click here, then press down a key." size="40">
<p id="log"></p>
```

```js
const input = document.querySelector('input');
const log = document.getElementById('log');

input.addEventListener('keydown', logKey);

function logKey(e) {
  log.textContent += ` ${e.code}`;
}
```

{{EmbedLiveSample("addEventListener_keydown_example")}}

### onkeydown equivalent

```js
input.onkeydown = logKey;
```

## Specifications

{{Specifications}}

## Browser compatibility

{{Compat}}

## See also

- [`input`](/en-US/docs/Web/API/HTMLElement/input_event)
- [`keypress`](/en-US/docs/Web/API/Element/keypress_event)
- [`keyup`](/en-US/docs/Web/API/Element/keyup_event)
- [Document `keydown` event](/en-US/docs/Web/API/Document/keydown_event)
