---
title: Global attributes
slug: Web/HTML/Global_attributes
tags:
  - Attribute
  - HTML
  - Reference
  - Web
browser-compat: html.global_attributes
spec-urls: https://html.spec.whatwg.org/multipage/dom.html#global-attributes
---

{{HTMLSidebar("Global_attributes")}}

**Global attributes** are attributes common to all HTML elements; they can be used on all elements, though they may have no effect on some elements.

Global attributes may be specified on all [HTML elements](/en-US/docs/Web/HTML/Element), _even those not specified in the standard_. That means that any non-standard elements must still permit these attributes, even though using those elements means that the document is no longer HTML5-compliant. For example, HTML5-compliant browsers hide content marked as `<foo hidden>...</foo>`, even though `<foo>` is not a valid HTML element.

In addition to the basic HTML global attributes, the following global attributes also exist:

- {{HTMLAttrDef("xml:lang")}} and {{HTMLAttrDef("xml:base")}} — these are inherited from the XHTML specifications and deprecated, but kept for compatibility purposes.
- The multiple **[`aria-*`](/en-US/docs/Web/Accessibility/ARIA)** attributes, used for improving accessibility.
- The [event handler](/en-US/docs/Web/Events/Event_handlers) attributes: **`onabort`**, **`onautocomplete`**, **`onautocompleteerror`**, **`onblur`**, **`oncancel`**, **`oncanplay`**, **`oncanplaythrough`**, **`onchange`**, **`onclick`**, **`onclose`**, **`oncontextmenu`**, **`oncuechange`**, **`ondblclick`**, **`ondrag`**, **`ondragend`**, **`ondragenter`**, **`ondragleave`**, **`ondragover`**, **`ondragstart`**, **`ondrop`**, **`ondurationchange`**, **`onemptied`**, **`onended`**, **`onerror`**, **`onfocus`**, **`oninput`**, **`oninvalid`**, **`onkeydown`**, **`onkeypress`**, **`onkeyup`**, **`onload`**, **`onloadeddata`**, **`onloadedmetadata`**, **`onloadstart`**, **`onmousedown`**, **`onmouseenter`**, **`onmouseleave`**, **`onmousemove`**, **`onmouseout`**, **`onmouseover`**, **`onmouseup`**, **`onmousewheel`**, **`onpause`**, **`onplay`**, **`onplaying`**, **`onprogress`**, **`onratechange`**, **`onreset`**, **`onresize`**, **`onscroll`**, **`onseeked`**, **`onseeking`**, **`onselect`**, **`onshow`**, **`onsort`**, **`onstalled`**, **`onsubmit`**, **`onsuspend`**, **`ontimeupdate`**, **`ontoggle`**, **`onvolumechange`**, **`onwaiting`**.

## List of global attributes

- [{{HTMLAttrDef("accesskey")}}](/en-US/docs/Web/HTML/Global_attributes/accesskey)
  - : Provides a hint for generating a keyboard shortcut for the current element. This attribute consists of a space-separated list of characters. The browser should use the first one that exists on the computer keyboard layout.
- [{{HTMLAttrDef("autocapitalize")}}](/en-US/docs/Web/HTML/Global_attributes/autocapitalize)

  - : Controls whether and how text input is automatically capitalized as it is entered/edited by the user. It can have the following values:

    - `off` or `none`, no autocapitalization is applied (all letters default to lowercase)
    - `on` or `sentences`, the first letter of each sentence defaults to a capital letter; all other letters default to lowercase
    - `words`, the first letter of each word defaults to a capital letter; all other letters default to lowercase
    - `characters`, all letters should default to uppercase

- [{{HTMLAttrDef("autofocus")}}](/en-US/docs/Web/HTML/Global_attributes/autofocus)
  - : Indicates that an element is to be focused on page load, or as soon as the {{HTMLElement("dialog")}} it is part of is displayed. This attribute is a boolean, initially false.
- [{{HTMLAttrDef("class")}}](/en-US/docs/Web/HTML/Global_attributes/class)
  - : A space-separated list of the classes of the element. Classes allows CSS and JavaScript to select and access specific elements via the [class selectors](/en-US/docs/Web/CSS/Class_selectors) or functions like the method {{DOMxRef("Document.getElementsByClassName()")}}.
- [{{HTMLAttrDef("contenteditable")}}](/en-US/docs/Web/HTML/Global_attributes/contenteditable)

  - : An enumerated attribute indicating if the element should be editable by the user. If so, the browser modifies its widget to allow editing. The attribute must take one of the following values:

    - `true` or the _empty string_, which indicates that the element must be editable;
    - `false`, which indicates that the element must not be editable.

- [{{HTMLAttrDef("contextmenu")}}](/en-US/docs/Web/HTML/Global_attributes/contextmenu) {{deprecated_inline}}
  - : The [**`id`**](#attr-id) of a {{HTMLElement("menu")}} to use as the contextual menu for this element.
- [{{HTMLAttrDef("data-*")}}](/en-US/docs/Web/HTML/Global_attributes/data-*)
  - : Forms a class of attributes, called custom data attributes, that allow proprietary information to be exchanged between the [HTML](/en-US/docs/Web/HTML) and its {{glossary("DOM")}} representation that may be used by scripts. All such custom data are available via the {{DOMxRef("HTMLElement")}} interface of the element the attribute is set on. The {{DOMxRef("HTMLElement.dataset")}} property gives access to them.
- [{{HTMLAttrDef("dir")}}](/en-US/docs/Web/HTML/Global_attributes/dir)

  - : An enumerated attribute indicating the directionality of the element's text. It can have the following values:

    - `ltr`, which means _left to right_ and is to be used for languages that are written from the left to the right (like English);
    - `rtl`, which means _right to left_ and is to be used for languages that are written from the right to the left (like Arabic);
    - `auto`, which lets the user agent decide. It uses a basic algorithm as it parses the characters inside the element until it finds a character with a strong directionality, then it applies that directionality to the whole element.

- [{{HTMLAttrDef("draggable")}}](/en-US/docs/Web/HTML/Global_attributes/draggable)

  - : An enumerated attribute indicating whether the element can be dragged, using the [Drag and Drop API](/en-US/docs/Web/API/HTML_Drag_and_Drop_API). It can have the following values:

    - `true`, which indicates that the element may be dragged
    - `false`, which indicates that the element may not be dragged.

- [{{HTMLAttrDef("enterkeyhint")}}](/en-US/docs/Web/HTML/Global_attributes/enterkeyhint)
  - : Hints what action label (or icon) to present for the enter key on virtual keyboards.
- [{{HTMLAttrDef("exportparts")}}](/en-US/docs/Web/HTML/Global_attributes/exportparts) {{Experimental_Inline}}
  - : Used to transitively export shadow parts from a nested shadow tree into a containing light tree.
- [{{HTMLAttrDef("hidden")}}](/en-US/docs/Web/HTML/Global_attributes/hidden)
  - : A Boolean attribute indicates that the element is not yet, or is no longer, _relevant_. For example, it can be used to hide elements of the page that can't be used until the login process has been completed. The browser won't render such elements. This attribute must not be used to hide content that could legitimately be shown.
- [{{HTMLAttrDef("id")}}](/en-US/docs/Web/HTML/Global_attributes/id)
  - : Defines a unique identifier (ID) which must be unique in the whole document. Its purpose is to identify the element when linking (using a fragment identifier), scripting, or styling (with CSS).
- [{{HTMLAttrDef("inputmode")}}](/en-US/docs/Web/HTML/Global_attributes/inputmode)
  - : Provides a hint to browsers as to the type of virtual keyboard configuration to use when editing this element or its contents. Used primarily on {{HTMLElement("input")}} elements, but is usable on any element while in {{HTMLAttrxRef("contenteditable")}} mode.
- [{{HTMLAttrDef("is")}}](/en-US/docs/Web/HTML/Global_attributes/is)
  - : Allows you to specify that a standard HTML element should behave like a registered custom built-in element (see [Using custom elements](/en-US/docs/Web/Web_Components/Using_custom_elements) for more details).

> **Note:** The `item*` attributes are part of the [WHATWG HTML Microdata feature](https://html.spec.whatwg.org/multipage/microdata.html#microdata).

- [{{HTMLAttrDef("itemid")}}](/en-US/docs/Web/HTML/Global_attributes/itemid)
  - : The unique, global identifier of an item.
- [{{HTMLAttrDef("itemprop")}}](/en-US/docs/Web/HTML/Global_attributes/itemprop)
  - : Used to add properties to an item. Every HTML element may have an `itemprop` attribute specified, where an `itemprop` consists of a name and value pair.
- [{{HTMLAttrDef("itemref")}}](/en-US/docs/Web/HTML/Global_attributes/itemref)
  - : Properties that are not descendants of an element with the `itemscope` attribute can be associated with the item using an `itemref`. It provides a list of element ids (not `itemid`s) with additional properties elsewhere in the document.
- [{{HTMLAttrDef("itemscope")}}](/en-US/docs/Web/HTML/Global_attributes/itemscope)
  - : `itemscope` (usually) works along with {{HTMLAttrxRef("itemtype")}} to specify that the HTML contained in a block is about a particular item. `itemscope` creates the Item and defines the scope of the `itemtype` associated with it. `itemtype` is a valid URL of a vocabulary (such as [schema.org](https://schema.org/)) that describes the item and its properties context.
- [{{HTMLAttrDef("itemtype")}}](/en-US/docs/Web/HTML/Global_attributes/itemtype)
  - : Specifies the URL of the vocabulary that will be used to define `itemprop`s (item properties) in the data structure. {{HTMLAttrxRef("itemscope")}} is used to set the scope of where in the data structure the vocabulary set by `itemtype` will be active.
- [{{HTMLAttrDef("lang")}}](/en-US/docs/Web/HTML/Global_attributes/lang)
  - : Helps define the language of an element: the language that non-editable elements are in, or the language that editable elements should be written in by the user. The attribute contains one "language tag" (made of hyphen-separated "language subtags") in the format defined in {{RFC(5646, "Tags for Identifying Languages (also known as BCP 47)")}}. [**xml:lang**](#attr-xml:lang) has priority over it.
- [{{HTMLAttrDef("nonce")}}](/en-US/docs/Web/HTML/Global_attributes/nonce)
  - : A cryptographic nonce ("number used once") which can be used by [Content Security Policy](/en-US/docs/Web/HTTP/CSP) to determine whether or not a given fetch will be allowed to proceed.
- [{{HTMLAttrDef("part")}}](/en-US/docs/Web/HTML/Global_attributes/part)
  - : A space-separated list of the part names of the element. Part names allows CSS to select and style specific elements in a shadow tree via the {{CSSxRef("::part")}} pseudo-element.
- [{{HTMLAttrDef("slot")}}](/en-US/docs/Web/HTML/Global_attributes/slot)
  - : Assigns a slot in a [shadow DOM](/en-US/docs/Web/Web_Components/Using_shadow_DOM) shadow tree to an element: An element with a `slot` attribute is assigned to the slot created by the {{HTMLElement("slot")}} element whose {{HTMLAttrxRef("name", "slot")}} attribute's value matches that `slot` attribute's value.
- [{{HTMLAttrDef("spellcheck")}}](/en-US/docs/Web/HTML/Global_attributes/spellcheck)

  - : An enumerated attribute defines whether the element may be checked for spelling errors. It may have the following values:

    - `true`, which indicates that the element should be, if possible, checked for spelling errors;
    - `false`, which indicates that the element should not be checked for spelling errors.

- [{{HTMLAttrDef("style")}}](/en-US/docs/Web/HTML/Global_attributes/style)
  - : Contains [CSS](/en-US/docs/Web/CSS) styling declarations to be applied to the element. Note that it is recommended for styles to be defined in a separate file or files. This attribute and the {{HTMLElement("style")}} element have mainly the purpose of allowing for quick styling, for example for testing purposes.
- [{{HTMLAttrDef("tabindex")}}](/en-US/docs/Web/HTML/Global_attributes/tabindex)

  - : An integer attribute indicating if the element can take input focus (is _focusable_), if it should participate to sequential keyboard navigation, and if so, at what position. It can take several values:

    - a _negative value_ means that the element should be focusable, but should not be reachable via sequential keyboard navigation;
    - `0` means that the element should be focusable and reachable via sequential keyboard navigation, but its relative order is defined by the platform convention;
    - a _positive value_ means that the element should be focusable and reachable via sequential keyboard navigation; the order in which the elements are focused is the increasing value of the [**tabindex**](#attr-tabindex). If several elements share the same tabindex, their relative order follows their relative positions in the document.

- [{{HTMLAttrDef("title")}}](/en-US/docs/Web/HTML/Global_attributes/title)
  - : Contains a text representing advisory information related to the element it belongs to. Such information can typically, but not necessarily, be presented to the user as a tooltip.
- [{{HTMLAttrDef("translate")}}](/en-US/docs/Web/HTML/Global_attributes/translate)

  - : An enumerated attribute that is used to specify whether an element's attribute values and the values of its {{DOMxRef("Text")}} node children are to be translated when the page is localized, or whether to leave them unchanged. It can have the following values:

    - empty string and `yes`, which indicates that the element will be translated.
    - `no`, which indicates that the element will not be translated.

## Specifications

{{Specifications}}

## Browser compatibility

{{Compat}}

## See also

- {{DOMxRef("Element")}} and {{DOMxRef("GlobalEventHandlers")}} interfaces that allow to query most global attributes.
