---
title: Features restricted to secure contexts
slug: Web/Security/Secure_Contexts/features_restricted_to_secure_contexts
tags:
  - API
  - Browsers
  - Reference
  - Secure contexts
  - Security
  - Web
  - features
  - support
---
This reference lists the web platform features available only in secure contexts — see [Secure Contexts](/en-US/docs/Web/Security/Secure_Contexts) for a definition and more details.

## Current features available only in secure contexts

This section lists all the APIs available only in secure contexts, along with browser versions the limitation was introduced in, as appropriate.

> **Note:** Only the browsers that actually support secure contexts are listed in this document. [See here](/en-US/docs/Web/Security/Secure_Contexts#browser_compatibility) for information on secure contexts support.

| API                                                                                                                    | Chrome/Opera  | Edge                                                                                                             | Safari                                                                                  | Firefox                                                          |
| ---------------------------------------------------------------------------------------------------------------------- | ------------- | ---------------------------------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------- | ---------------------------------------------------------------- |
| [Async Clipboard API](/en-US/docs/Web/API/Clipboard)                                                                   | 66            | Not supported                                                                                                    | Not supported                                                                           | 63                                                               |
| [Background Sync](https://wicg.github.io/BackgroundSync/spec/) (see {{domxref("SyncManager")}}, for example) | 49            | Not supported                                                                                                    | Not supported                                                                           | Not supported                                                    |
| [`Cache-Control: immutable`](/en-US/docs/Web/HTTP/Headers/Cache-Control)                                               | Not supported | 15                                                                                                               | 11                                                                                      | 49                                                               |
| [Credential Management API](/en-US/docs/Web/API/Credential_Management_API)                                             | 51            | Not supported                                                                                                    | Not supported                                                                           | Not supported                                                    |
| [Generic Sensor API](https://w3c.github.io/sensors/)                                                                   | 67            | Not supported                                                                                                    | Not supported                                                                           | Not supported                                                    |
| [Payment Request API](/en-US/docs/Web/API/Payment_Request_API).                                                        | 61            | [15](https://blogs.windows.com/msedgedev/2017/04/11/introducing-edgehtml-15/)                                    | [11.1](https://webkit.org/blog/8182/introducing-the-payment-request-api-for-apple-pay/) | In development (behind the `dom.payments.request.enabled` pref). |
| [Push API](/en-US/docs/Web/API/Push_API)                                                                               | 42            | [17](https://blogs.windows.com/msedgedev/2017/12/19/service-workers-going-beyond-page/)                          | Not supported                                                                           | 44                                                               |
| [Reporting API](/en-US/docs/Web/API/Reporting_API)                                                                     | Supported     | Not supported                                                                                                    | Not supported                                                                           | Behind flag since Fx 65                                          |
| [Service Workers](/en-US/docs/Web/API/Service_Worker_API)                                                              | 40            | [17](https://blogs.windows.com/msedgedev/2017/12/19/service-workers-going-beyond-page/)                          | [11.1](https://webkit.org/blog/8216/new-webkit-features-in-safari-11-1/)                | 44                                                               |
| [Storage API](/en-US/docs/Web/API/Storage_API)                                                                         | 55            | Not supported                                                                                                    | Not supported                                                                           | 51                                                               |
| [Web Authentication API](/en-US/docs/Web/API/Web_Authentication_API)                                                   | 65            | [In preview (17)](https://blogs.windows.com/msedgedev/2018/07/30/introducing-web-authentication-microsoft-edge/) | [In development](https://bugs.webkit.org/show_bug.cgi?id=181943)                        | 60                                                               |
| [Web Bluetooth](/en-US/docs/Web/API/Web_Bluetooth_API)                                                                 | 56            | Not supported                                                                                                    | Not supported                                                                           | Not supported                                                    |
| [Web MIDI](https://webaudio.github.io/web-midi-api/) (see {{domxref("MIDIAccess")}}, for example)               | 43            | Not supported                                                                                                    | Not supported                                                                           | Not supported                                                    |
| [Web Crypto API](/en-US/docs/Web/API/Web_Crypto_API)                                                                   | 60            | 79                                                                                                               | Not supported                                                                           | 75                                                               |
| [EyeDropper API](/en-US/docs/Web/API/EyeDropper)                                                                   | 96            | Not supported                                                                                                               | Not supported                                                                           | Not supported                                                               |

## Secure context restrictions that vary by browser

Some browsers may decide to disable certain APIs in non-secure contexts or apply other restrictions/security measures, despite the spec not requiring them. This section lists any such differences existing in browsers.

| API                                                                                    | Chrome                                                                                                                                                                                                                                                                                                                     | Edge                                                                      | Safari                                                                                                                    | Firefox                                                                                                                                                                                                               |
| -------------------------------------------------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- |
| {{domxref("Geolocation")}}                                                   | [Restricted to secure contexts in 50](https://developers.google.com/web/updates/2016/04/geolocation-on-secure-contexts-only)                                                                                                                                                                                               |                                                                           | Restricted to secure contexts in 10                                                                                       |                                                                                                                                                                                                                       |
| [Device Orientation / Device Motion](/en-US/docs/Web/Events/Detecting_device_orientation) | Deprecation warning                                                                                                                                                                                                                                                                                                        |                                                                           |                                                                                                                           |                                                                                                                                                                                                                       |
| [Encrypted Media Extensions](/en-US/docs/Web/API/Encrypted_Media_Extensions_API)       | [Restricted to secure contexts in 58](https://developers.google.com/web/updates/2017/03/chrome-58-deprecations#remove_eme_from_non-secure_contexts)                                                                                                                                                                        |                                                                           |                                                                                                                           | [Planned](https://bugzilla.mozilla.org/show_bug.cgi?id=1322517).                                                                                                                                                      |
| [getUserMedia()](/en-US/docs/Web/API/MediaDevices/getUserMedia)                        | [Restricted to secure contexts in Chrome 47](https://developers.google.com/web/updates/2015/10/chrome-47-webrtc)                                                                                                                                                                                                           |                                                                           |                                                                                                                           | Temporary access available only (users cannot choose "Remember this decision" in the permission request dialog). [Restricted to secure contexts in Firefox 68.](https://bugzilla.mozilla.org/show_bug.cgi?id=1335740) |
| [Notifications](/en-US/docs/Web/API/Notifications_API)                                 | [Restricted to secure contexts in Chrome 62](https://developers.google.com/web/updates/2017/09/chrome-62-deprecations#remove_usage_of_notifications_from_insecure_iframes)                                                                                                                                                 |                                                                           |                                                                                                                           | [Restricted to secure contexts in Firefox 67.](https://bugzilla.mozilla.org/show_bug.cgi?id=1429432)                                                                                                                  |
| [<a ping> attribute](/en-US/docs/Web/HTML/Element/a#attr-ping)                         |                                                                                                                                                                                                                                                                                                                            | Disabled in non-secure contexts                                           |                                                                                                                           | Support has been added since Firefox 3, but never been enabled by default (behind the `browser.send_pings` pref).                                                                                                     |
| [Presentation](/en-US/docs/Web/API/Presentation_API)                                   | [Deprecation warning in 61](https://developers.google.com/web/updates/2017/08/chrome-61-deprecations#deprecate_and_remove_presentation_api_on_insecure_contexts)                                                                                                                                                           |                                                                           |                                                                                                                           |                                                                                                                                                                                                                       |
| [Web Crypto API](/en-US/docs/Web/API/Web_Crypto_API)                                   | Has been restricted to HTTPS since early days (API was visible in HTTP as well but operations failed). [Restricted to secure contexts in Chrome 60](https://developers.google.com/web/updates/2017/06/chrome-60-deprecations#cryptosubtle_now_requires_a_secure_origin) (API is no longer visible on non-secure contexts). | Restricted to secure contexts from Edge 79                                |                                                                                                                           | Restricted to secure contexts in Firefox 75                                                                                                                                                                           |
| [registerProtocolHandler()](/en-US/docs/Web/API/Navigator/registerProtocolHandler)     |                                                                                                                                                                                                                                                                                                                            |                                                                           |                                                                                                                           |                                                                                                                                                                                                                       |

## See also

- [Secure contexts](/en-US/docs/Web/Security/Secure_Contexts)
- ["secure context" query on Chrome Platform Status](https://www.chromestatus.com/features#secure%20context)

{{QuickLinksWithSubpages("/en-US/docs/Web/Security")}}
