---
title: 'SVG: Scalable Vector Graphics'
slug: Web/SVG
tags:
  - 2D Graphics
  - Graphics
  - Icons
  - Images
  - Reference
  - Responsive Design
  - SVG
  - Scalable Graphics
  - Scalable Images
  - Vector Graphics
  - Web
  - l10n:priority
---
{{SVGRef}}

## Getting Started with SVG

**Scalable Vector Graphics (SVG)** are an [XML](/en-US/docs/Web/XML)-based markup language for describing two-dimensional based [vector graphics](https://en.wikipedia.org/wiki/Vector_graphics).

As such, it's a text-based, open Web standard for describing images that can be rendered cleanly at any size and are designed specifically to work well with other web standards including [CSS](/en-US/docs/Web/CSS), [DOM](/en-US/docs/Web/API/Document_Object_Model), [JavaScript](/en-US/docs/Web/JavaScript), and [SMIL](/en-US/docs/Web/SVG/SVG_animation_with_SMIL). SVG is, essentially, to graphics what [HTML](/en-US/docs/Web/HTML) is to text.

SVG images and their related behaviors are defined in [XML](/en-US/docs/Web/XML) text files, which means they can be searched, indexed, scripted, and compressed. Additionally, this means they can be created and edited with any text editor or with drawing software.

Compared to classic bitmapped image formats such as {{Glossary("JPEG")}} or {{Glossary("PNG")}}, SVG-format vector images can be rendered at any size without loss of quality and can be easily localized by updating the text within them, without the need of a graphical editor to do so. With proper libraries, SVG files can even be localized on-the-fly.

SVG has been developed by the [World Wide Web Consortium (W3C)](https://www.w3.org/) since 1999.

See also, [SVG Tutorial](/en-US/docs/Web/SVG/Tutorial)

## Documentation

- [SVG element reference](/en-US/docs/Web/SVG/Element)
  - : Details about each SVG element.
- [SVG attribute reference](/en-US/docs/Web/SVG/Attribute)
  - : Details about each SVG attribute.
- [SVG DOM interface reference](/en-US/docs/Web/API/Document_Object_Model#svg_interfaces)
  - : Details about the SVG DOM API, for interaction with JavaScript.
- [Applying SVG effects to HTML content](/en-US/docs/Web/SVG/Applying_SVG_effects_to_HTML_content)
  - : SVG works together with {{Glossary("HTML")}}, {{Glossary("CSS")}} and {{Glossary("JavaScript")}}. Use SVG to [enhance a regular HTML page or web application](/en-US/docs/Web/SVG/Tutorial/SVG_In_HTML_Introduction).

## Tools

- [SVG Test Suite](https://github.com/w3c/svgwg/wiki/Testing)
- [Markup Validator](https://validator.w3.org/#validate_by_input)

## Examples

- [SVG authoring guidelines](https://jwatt.org/svg/authoring/)
- [SVG as an image](/en-US/docs/Web/SVG/SVG_as_an_Image)
- [SVG animation with SMIL](/en-US/docs/Web/SVG/SVG_animation_with_SMIL)
- [SVG art gallery](https://plurib.us/1shot/2007/svg_gallery/)
- [D3](https://d3js.org) (JavaScript library for visualizing data with HTML, SVG, and CSS)
